from typing import List, Mapping, Optional
import pulumi
import pulumi_aws

class ECSLoadBalancer:
    load_balancer: pulumi_aws.lb.LoadBalancer = None
    target_group: pulumi_aws.lb.TargetGroup = None
    listener: pulumi_aws.lb.Listener = None


    def __init__(self, resource_name:str, subnet_ids:List[str],vpc_id:str, tags: Optional[Mapping[str, str]]) -> None:
        self.create_load_balancer(resource_name,subnet_ids,vpc_id,tags)

    def create_load_balancer(self, resource_name:str,subnet_ids:List[str],vpc_id:str, tags: Optional[Mapping[str, str]]):
        # Create a load balancer for the ECS service
        self.load_balancer = pulumi_aws.lb.LoadBalancer(f"{resource_name}-loadbalancer",
            internal=False,
            load_balancer_type="application",
            subnets=subnet_ids,
            tags=tags
        )

        # Create a target group for the ECS service
        self.target_group = pulumi_aws.lb.TargetGroup(f"{resource_name}-targetgroup",
            port=443,
            protocol="HTTPS",
            target_type="ip",
            vpc_id=vpc_id
        )

        # Create a listener for the load balancer
        self.listener = pulumi_aws.lb.Listener(f"{resource_name}-listener",
            load_balancer_arn=self.load_balancer.arn,
            port=80,
            default_actions=[{
                "type": "forward",
                "target_group_arn": self.target_group.arn
            }]
        )