import pulumi

from pulumi.output import Output
from pulumi_kubernetes.core.v1 import ConfigMap as cm
from pulumi_kubernetes.meta.v1 import ObjectMetaArgs

from pydantic.dataclasses import dataclass, ConfigDict
from typing import Optional, Mapping, List

from theia import ResourceOptions
from theia.utils.logger import Logger

logger = Logger("config-map")


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class MetadataArgs:
    annotations: Optional[Mapping[str, str]] = None
    cluster_name: Optional[str | Output[str]] = None
    finalizers: Optional[List[str]] = None
    labels: Optional[Mapping[str, str | Output[str]]] = None
    name: Optional[str] = None
    namespace: Optional[str] = None


class ConfigMap:
    def __new__(
        cls,
        resource_name: str,
        data: Optional[Mapping[str, str]] = None,
        immutable: Optional[bool] = False,
        metadata: Optional[MetadataArgs] = MetadataArgs(),
        opts: Optional[ResourceOptions] = None,
    ) -> cm:
        metadata_args = ObjectMetaArgs(
            name=metadata.name,
            namespace=metadata.namespace,
            cluster_name=metadata.cluster_name,
            annotations=metadata.annotations,
            finalizers=metadata.finalizers,
            labels=metadata.labels,
        )

        configmap = cm(
            resource_name,
            data=data,
            immutable=immutable,
            metadata=metadata_args,
            opts=opts,
        )

        pulumi.export(f"configmap---{resource_name}", {"id": configmap.id})

        return configmap
